@@ -1,11 +1,13 @@
 {
 
     package Mite::Class;
-    our $USES_MITE = "Mite::Class";
-    our $MITE_SHIM = "Mite::Shim";
     use strict;
     use warnings;
 
+    our $USES_MITE    = "Mite::Class";
+    our $MITE_SHIM    = "Mite::Shim";
+    our $MITE_VERSION = "0.006010";
+
     BEGIN {
         require Scalar::Util;
         *bare    = \&Mite::Shim::bare;
@@ -326,52 +328,6 @@
         return $self;
     }
 
-    sub BUILDALL {
-        my $class = ref( $_[0] );
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        $_->(@_) for @{ $meta->{BUILD} || [] };
-    }
-
-    sub DESTROY {
-        my $self  = shift;
-        my $class = ref($self) || $self;
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        my $in_global_destruction =
-          defined ${^GLOBAL_PHASE}
-          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
-          : Devel::GlobalDestruction::in_global_destruction();
-        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
-            my $e = do {
-                local ( $?, $@ );
-                eval { $demolisher->( $self, $in_global_destruction ) };
-                $@;
-            };
-            no warnings 'misc';    # avoid (in cleanup) warnings
-            die $e if $e;          # rethrow
-        }
-        return;
-    }
-
-    sub __META__ {
-        no strict 'refs';
-        no warnings 'once';
-        my $class = shift;
-        $class = ref($class) || $class;
-        my $linear_isa = mro::get_linear_isa($class);
-        return {
-            BUILD => [
-                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                map { "$_\::BUILD" } reverse @$linear_isa
-            ],
-            DEMOLISH => [
-                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } @$linear_isa
-            ],
-            HAS_BUILDARGS        => $class->can('BUILDARGS'),
-            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
-        };
-    }
-
     sub DOES {
         my ( $self, $role ) = @_;
         our %DOES;
